==> ejc-ztpcdc-impl-3.0.0-20230505.055326-10-sources.jar: com/ejianc/business/dc/vo/DcFileissueRecordVO.java <==
package com.ejianc.business.dc.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 文件签发信息
 * 
 * @author generator
 * 
 */
public class DcFileissueRecordVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long centerId; // 分发中心主键ID
    private Integer orderNum; // 顺序号
    private String fileCode; // 文件编号
    private String fileName; // 文件名称
    private String fileInternalCode; // 文件内部编码
    private String fileVsn; // 文件版本
    private Long receiveDeptId; // 接收人部门id
    private String receiveUserCode; // 接收人编号
    private String receiveUserName; // 接收人姓名
    private Integer num; // 份数
    private String hostFlag; // 主办/协办（Y为主办，N为协办）
    private Long createDeptId; // 创建部门id
    

    public Long getCenterId() {
        return centerId;
    }

    public void setCenterId(Long centerId) {
        this.centerId = centerId;
    }
    public Integer getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(Integer orderNum) {
        this.orderNum = orderNum;
    }
    public String getFileCode() {
        return fileCode;
    }

    public void setFileCode(String fileCode) {
        this.fileCode = fileCode;
    }
    public String getFileName() {
        return fileName;
    }

    public void setFileName(String fileName) {
        this.fileName = fileName;
    }
    public String getFileInternalCode() {
        return fileInternalCode;
    }

    public void setFileInternalCode(String fileInternalCode) {
        this.fileInternalCode = fileInternalCode;
    }
    public String getFileVsn() {
        return fileVsn;
    }

    public void setFileVsn(String fileVsn) {
        this.fileVsn = fileVsn;
    }
    public Long getReceiveDeptId() {
        return receiveDeptId;
    }

    public void setReceiveDeptId(Long receiveDeptId) {
        this.receiveDeptId = receiveDeptId;
    }
    public String getReceiveUserCode() {
        return receiveUserCode;
    }

    public void setReceiveUserCode(String receiveUserCode) {
        this.receiveUserCode = receiveUserCode;
    }
    public String getReceiveUserName() {
        return receiveUserName;
    }

    public void setReceiveUserName(String receiveUserName) {
        this.receiveUserName = receiveUserName;
    }
    public Integer getNum() {
        return num;
    }

    public void setNum(Integer num) {
        this.num = num;
    }
    public String getHostFlag() {
        return hostFlag;
    }

    public void setHostFlag(String hostFlag) {
        this.hostFlag = hostFlag;
    }
    public Long getCreateDeptId() {
        return createDeptId;
    }

    public void setCreateDeptId(Long createDeptId) {
        this.createDeptId = createDeptId;
    }
    
}

==> ejc-ztpcdc-impl-3.0.0-20230531.020113-32-sources.jar: com/ejianc/business/dc/vo/DcFileissueRecordVO.java <==
package com.ejianc.business.dc.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 文件签发信息
 * 
 * @author generator
 * 
 */
public class DcFileissueRecordVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long centerId; // 分发中心主键ID
    private Integer orderNum; // 顺序号
    private String fileCode; // 文件编号
    private String fileName; // 文件名称
    private String fileInternalCode; // 文件内部编码
    private String fileVsn; // 文件版本
    private String receiveDeptName; // 接收人部门名称
    private Long receiveUserId;//接收人ID
    private String receiveUserCode; // 接收人编号
    private String receiveUserName; // 接收人姓名
    private Integer num; // 份数
    private String hostFlag; // 主办/协办（Y为主办，N为协办）
    private Long createDeptId; // 创建部门id
    

    public Long getCenterId() {
        return centerId;
    }

    public void setCenterId(Long centerId) {
        this.centerId = centerId;
    }
    public Integer getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(Integer orderNum) {
        this.orderNum = orderNum;
    }
    public String getFileCode() {
        return fileCode;
    }

    public void setFileCode(String fileCode) {
        this.fileCode = fileCode;
    }
    public String getFileName() {
        return fileName;
    }

    public void setFileName(String fileName) {
        this.fileName = fileName;
    }
    public String getFileInternalCode() {
        return fileInternalCode;
    }

    public void setFileInternalCode(String fileInternalCode) {
        this.fileInternalCode = fileInternalCode;
    }
    public String getFileVsn() {
        return fileVsn;
    }

    public void setFileVsn(String fileVsn) {
        this.fileVsn = fileVsn;
    }

    public String getReceiveDeptName() {
        return receiveDeptName;
    }

    public void setReceiveDeptName(String receiveDeptName) {
        this.receiveDeptName = receiveDeptName;
    }

    public String getReceiveUserCode() {
        return receiveUserCode;
    }

    public void setReceiveUserCode(String receiveUserCode) {
        this.receiveUserCode = receiveUserCode;
    }
    public String getReceiveUserName() {
        return receiveUserName;
    }

    public void setReceiveUserName(String receiveUserName) {
        this.receiveUserName = receiveUserName;
    }
    public Integer getNum() {
        return num;
    }

    public void setNum(Integer num) {
        this.num = num;
    }
    public String getHostFlag() {
        return hostFlag;
    }
    @ReferSerialTransfer(referCode = "idm-user")
    public Long getReceiveUserId() {
        return receiveUserId;
    }
    @ReferDeserialTransfer
    public void setReceiveUserId(Long receiveUserId) {
        this.receiveUserId = receiveUserId;
    }

    public void setHostFlag(String hostFlag) {
        this.hostFlag = hostFlag;
    }
    @ReferSerialTransfer(referCode = "idm-dept")
    public Long getCreateDeptId() {
        return createDeptId;
    }
    @ReferDeserialTransfer
    public void setCreateDeptId(Long createDeptId) {
        this.createDeptId = createDeptId;
    }
    
}
